Package: lineagespot
Title: Detection of SARS-CoV-2 lineages in wastewater samples using
        next-generation sequencing
Version: 1.14.0
Date: 2021-03-24
Authors@R: c(
    person(given = "Nikolaos",
            family = "Pechlivanis",
            role = c("aut", "cre"),
            email = "inab.bioinformatics@lists.certh.gr",
            comment = c(ORCID = "0000-0003-2502-612X")),
    person("Maria", "Tsagiopoulou", email = "-", role = "aut"),
    person("Maria Christina", "Maniou", email = "-", role = "aut"),
    person("Anastasis", "Togkousidis", email = "-", role = "aut"),
    person("Evangelia", "Mouchtaropoulou", email = "-", role = "aut"),
    person("Taxiarchis", "Chassalevris", email = "-", role = "aut"),
    person("Serafeim", "Chaintoutis", email = "-", role = "aut"),
    person("Chrysostomos", "Dovas", email = "-", role = "aut"),
    person("Maria", "Petala", email = "-", role = "aut"),
    person("Margaritis", "Kostoglou", email = "-", role = "aut"),
    person("Thodoris", "Karapantsios", email = "-", role = "aut"),
    person("Stamatia", "Laidou", email = "-", role = "aut"),
    person("Elisavet", "Vlachonikola", email = "-", role = "aut"),
    person("Aspasia", "Orfanou", email = "-", role = "aut"),
    person("Styliani-Christina", "Fragkouli", email = "-", role = "aut"),
    person("Sofoklis", "Keisaris", email = "-", role = "aut"),
    person("Anastasia", "Chatzidimitriou", email = "-", role = "aut"),
    person("Agis", "Papadopoulos", email = "-", role = "aut"),
    person("Nikolaos", "Papaioannou", email = "-", role = "aut"),
    person("Anagnostis", "Argiriou", email = "-", role = "aut"),
    person("Fotis E.", "Psomopoulos", email = "-", role = "aut")
    )
Description: Lineagespot is a framework written in R, and aims to identify 
    SARS-CoV-2 related mutations based on a single (or a list) of variant(s) 
    file(s) (i.e., variant calling format). The method can facilitate the 
    detection of SARS-CoV-2 lineages in wastewater samples using next 
    generation sequencing, and attempts to infer the potential distribution 
    of the SARS-CoV-2 lineages. 
License: MIT + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.1.2
biocViews: VariantDetection, VariantAnnotation, Sequencing
Imports: VariantAnnotation, MatrixGenerics, SummarizedExperiment,
        data.table, stringr, httr, utils
Suggests: BiocStyle, RefManageR, rmarkdown, knitr, testthat (>= 3.0.0)
URL: https://github.com/BiodataAnalysisGroup/lineagespot
BugReports: https://github.com/BiodataAnalysisGroup/lineagespot/issues
BiocType: Software
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/lineagespot
git_branch: RELEASE_3_22
git_last_commit: c41b331
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:44:51 UTC; biocbuild
Author: Nikolaos Pechlivanis [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2502-612X>),
  Maria Tsagiopoulou [aut],
  Maria Christina Maniou [aut],
  Anastasis Togkousidis [aut],
  Evangelia Mouchtaropoulou [aut],
  Taxiarchis Chassalevris [aut],
  Serafeim Chaintoutis [aut],
  Chrysostomos Dovas [aut],
  Maria Petala [aut],
  Margaritis Kostoglou [aut],
  Thodoris Karapantsios [aut],
  Stamatia Laidou [aut],
  Elisavet Vlachonikola [aut],
  Aspasia Orfanou [aut],
  Styliani-Christina Fragkouli [aut],
  Sofoklis Keisaris [aut],
  Anastasia Chatzidimitriou [aut],
  Agis Papadopoulos [aut],
  Nikolaos Papaioannou [aut],
  Anagnostis Argiriou [aut],
  Fotis E. Psomopoulos [aut]
Maintainer: Nikolaos Pechlivanis <inab.bioinformatics@lists.certh.gr>
