# Generated by roxygen2: do not edit by hand

export(get_lineage_report)
export(is_gff3)
export(lineagespot)
export(lineagespot_hits)
export(list_input)
export(list_vcf)
export(merge_vcf)
export(uniq_variants)
import(data.table)
importFrom(MatrixGenerics,rowRanges)
importFrom(SummarizedExperiment,assays)
importFrom(VariantAnnotation,fixed)
importFrom(VariantAnnotation,info)
importFrom(VariantAnnotation,readVcf)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(stringr,str_detect)
importFrom(stringr,str_length)
importFrom(stringr,str_remove)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_squish)
importFrom(stringr,str_to_upper)
importFrom(utils,globalVariables)
